@@ -14,6 +14,12 @@ import (
 	"github.com/stretchr/testify/assert"
 )
 
+const (
+	abc   = "/abc"
+	abcd  = "/a/b/c/d"
+	cdefg = "/c/d/e/f/g"
+)
+
 var testParentCases = []testParentCase{
 	{
 		Case:          "Inside Home folder",
@@ -707,7 +713,7 @@ func TestFolderPathCustomMappedLocations(t *testing.T) {
 	env.On("Shell").Return(shell.GENERIC)
 
 	template.Cache = new(cache.Template)
-	template.Init(env, nil)
+	template.Init(env, nil, nil)
 
 	props := properties.Map{
 		properties.Style: FolderType,
@@ -753,7 +759,7 @@ func TestReplaceMappedLocations(t *testing.T) {
 		env.On("Home").Return("/a/b/k")
 
 		template.Cache = new(cache.Template)
-		template.Init(env, nil)
+		template.Init(env, nil, nil)
 
 		props := properties.Map{
 			MappedLocationsEnabled: tc.MappedLocationsEnabled,
@@ -813,7 +819,7 @@ func TestGetPwd(t *testing.T) {
 		env.On("Shell").Return(shell.PWSH)
 
 		template.Cache = new(cache.Template)
-		template.Init(env, nil)
+		template.Init(env, nil, nil)
 
 		props := properties.Map{
 			MappedLocationsEnabled: tc.MappedLocationsEnabled,
