@@ -6,8 +6,7 @@ import (
 )
 
 type WindowsRegistry struct {
-	props properties.Properties
-	env   runtime.Environment
+	Base
 
 	Value string
 }
@@ -23,11 +22,6 @@ func (wr *WindowsRegistry) Template() string {
 	return " {{ .Value }} "
 }
 
-func (wr *WindowsRegistry) Init(props properties.Properties, env runtime.Environment) {
-	wr.props = props
-	wr.env = env
-}
-
 func (wr *WindowsRegistry) Enabled() bool {
 	if wr.env.GOOS() != runtime.WINDOWS {
 		return false
